@@ -7,3 +7,9 @@ create table person (
     created         timestamp not null    
 );
 
+create table disabled (
+    id              integer primary key not null,
+    name            varchar(128) not null,
+    created         timestamp not null    
+);
+
